==> nextcloud-31.0.4-1.0-any.pkg.tar.zst: usr/share/webapps/nextcloud/lib/l10n/th.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "ไม่สามารถเขียนลงในไดเรกทอรี \"config\"!",
    "This can usually be fixed by giving the web server write access to the config directory." : "โดยปกติสามารถแก้ไขได้โดยการให้สิทธิ์การเขียนสำหรับเว็บเซิร์ฟเวอร์ไปยังไดเร็กทอรี config",
    "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "แต่หากคุณต้องการให้ไฟล์ config.php อ่านอย่างเดียว ให้ตั้งค่าตัวเลือก \"config_is_read_only\" เป็น true",
    "See %s" : "ดู %s",
    "Sample configuration detected" : "ตรวจพบการกำหนดค่าตัวอย่าง",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "เราตรวจพบว่าการกำหนดค่าตัวอย่างถูกคัดลอกมา การกำหนดค่าลักษณะนี้สามารถทำลายการติดตั้งของคุณและไม่ได้รับการสนับสนุน โปรดอ่านเอกสารประกอบก่อนที่จะดำเนินการเปลี่ยนแปลงใน config.php",
    "The page could not be found on the server." : "ไม่พบหน้านี้บนเซิร์ฟเวอร์",
    "%s email verification" : "การยืนยันอีเมล %s",
    "Email verification" : "การยืนยันอีเมล",
    "Click the following button to confirm your email." : "คลิกปุ่มต่อไปนี้เพื่อยืนยันอีเมลของคุณ",
    "Click the following link to confirm your email." : "คลิกลิงก์ต่อไปนี้เพื่อยืนยันอีเมลของคุณ",
    "Confirm your email" : "ยืนยันอีเมล",
    "Other activities" : "กิจกรรมอื่น ๆ",
    "%1$s and %2$s" : "%1$s และ %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s และ %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s และ %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s และ %5$s",
    "PHP %s or higher is required." : "จำเป็นต้องมี PHP รุ่น %s หรือที่สูงกว่า ",
    "PHP with a version lower than %s is required." : "จำเป็นต้องมี PHP รุ่นต่ำกว่า %s",
    "%sbit or higher PHP required." : "จำเป็นต้องมี PHP %s บิตหรือสูงกว่า",
    "The command line tool %s could not be found" : "ไม่พบเครื่องมือบรรทัดคำสั่ง %s ",
    "The library %s is not available." : "ไลบรารี %s ไม่สามารถใช้ได้",
    "Server version %s or higher is required." : "จำเป็นต้องใช้เซิร์ฟเวอร์รุ่น %s หรือสูงกว่า",
    "Server version %s or lower is required." : "จำเป็นต้องใช้เซิร์ฟเวอร์รุ่น %s หรือต่ำกว่า",
    "Authentication" : "การตรวจสอบสิทธิ์",
    "Unknown filetype" : "ชนิดไฟล์ที่ไม่รู้จัก",
    "Invalid image" : "รูปภาพไม่ถูกต้อง",
    "Files" : "ไฟล์",
    "today" : "วันนี้",
    "tomorrow" : "พรุ่งนี้",
    "yesterday" : "เมื่อวานนี้",
    "_in %n day_::_in %n days_" : ["ใน %n วัน"],
    "_%n day ago_::_%n days ago_" : ["%n วันที่ผ่านมา"],
    "next month" : "เดือนถัดไป",
    "last month" : "เดือนที่แล้ว",
    "_in %n month_::_in %n months_" : ["ใน %n เดือน"],
    "_%n month ago_::_%n months ago_" : ["%n เดือนที่ผ่านมา"],
    "next year" : "ปีถัดไป",
    "last year" : "ปีที่แล้ว",
    "_%n year ago_::_%n years ago_" : ["%n ปีที่ผ่านมา"],
    "_%n hour ago_::_%n hours ago_" : ["%n ชั่วโมงที่ผ่านมา"],
    "_%n minute ago_::_%n minutes ago_" : ["%n นาทีที่ผ่านมา"],
    "in a few seconds" : "ในไม่กี่วินาที",
    "seconds ago" : "วินาทีที่ผ่านมา",
    "Empty file" : "ไฟล์ว่าง",
    "Dot files are not allowed" : "ไม่อนุญาตไฟล์จุด",
    "File already exists" : "มีไฟล์นี้อยู่แล้ว",
    "Templates" : "เทมเพลต",
    "Filename contains at least one invalid character" : "ชื่อไฟล์มีตัวอักษรที่ไม่ถูกต้องอย่างน้อย 1 ตัว",
    "Empty filename is not allowed" : "ชื่อไฟล์ห้ามว่างเปล่า",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "แอป \"%s\" ไม่สามารถติดตั้งได้ เพราะไฟล์ appInfo ไม่สามารถอ่านได้",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "ไม่สามารถติดตั้งแอป \"%s\" เนื่องจากแอปเข้ากับเซิร์ฟเวอร์รุ่นนี้ไม่ได้",
    "__language_name__" : "ไทย",
    "Apps" : "แอป",
    "Personal settings" : "การตั้งค่าส่วนบุคคล",
    "Administration settings" : "การตั้งค่าการดูแลระบบ",
    "Settings" : "การตั้งค่า",
    "Log out" : "ออกจากระบบ",
    "Accounts" : "บัญชี",
    "Email" : "อีเมล",
    "Fediverse" : "เฟดิเวิร์ส",
    "View %s on the fediverse" : "ดู %s บนเฟดิเวิร์ส",
    "Phone" : "โทรศัพท์",
    "Twitter" : "ทวิตเตอร์",
    "Website" : "เว็บไซต์",
    "Address" : "ที่อยู่",
    "Profile picture" : "รูปภาพโปรไฟล์",
    "About" : "เกี่ยวกับ",
    "Display name" : "ชื่อที่แสดง",
    "Additional settings" : "การตั้งค่าเพิ่มเติม",
    "Oracle connection could not be established" : "ไม่สามารถสร้างการเชื่อมต่อกับ Oracle ",
    "For the best results, please consider using a GNU/Linux server instead." : "เพื่อให้ได้ผลลัพธ์ที่ดีที่สุด โปรดพิจารณาใช้เซิร์ฟเวอร์ GNU/Linux แทน",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "ดูเหมือนว่าเซิร์ฟเวอร์ %s นี้ทำงานบน PHP 32 บิต และ open_basedir ได้ถูกกำหนดค่าใน php.ini ซึ่งจะมีปัญหากับไฟล์ที่มีขนาดใหญ่กว่า 4 GB และไม่แนะนำให้ใช้",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "กรุณาลบการตั้งค่า open_basedir ใน php.ini ของคุณ หรือเปลี่ยนไปใช้ PHP รุ่น 64 บิตแทน",
    "Set an admin password." : "ตั้งค่ารหัสผ่านผู้ดูแลระบบ",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "แบ็กเอนด์การแชร์ %s ต้องใช้อินเตอร์เฟซ OCP\\Share_Backend",
    "Sharing backend %s not found" : "ไม่พบแบ็กเอนด์การแชร์ %s",
    "Sharing backend for %s not found" : "ไม่พบแบ็กเอนด์การแชร์สำหรับ %s",
    "Unknown share type" : "ไม่รู้จักประเภทของแชร์",
    "You are not allowed to share %s" : "คุณไม่ได้รับอนุญาตให้แชร์ %s",
    "Cannot increase permissions of %s" : "ไม่สามารถเพิ่มสิทธิ์ของ %s",
    "Expiration date is in the past" : "วันหมดอายุอยู่ในอดีต",
    "Could not find category \"%s\"" : "ไม่สามารถหาหมวดหมู่ \"%s\"",
    "Sunday" : "วันอาทิตย์",
    "Monday" : "วันจันทร์",
    "Tuesday" : "วันอังคาร",
    "Wednesday" : "วันพุธ",
    "Thursday" : "วันพฤหัสบดี",
    "Friday" : "วันศุกร์",
    "Saturday" : "วันเสาร์",
    "Sun." : "อา.",
    "Mon." : "จ.",
    "Tue." : "อ.",
    "Wed." : "พ.",
    "Thu." : "พฤ.",
    "Fri." : "ศ.",
    "Sat." : "ส.",
    "Su" : "อา",
    "Mo" : "จ",
    "Tu" : "อ",
    "We" : "พ",
    "Th" : "พฤ",
    "Fr" : "ศ",
    "Sa" : "ส",
    "January" : "มกราคม",
    "February" : "กุมภาพันธ์",
    "March" : "มีนาคม",
    "April" : "เมษายน",
    "May" : "พฤษภาคม",
    "June" : "มิถุนายน",
    "July" : "กรกฏาคม",
    "August" : "สิงหาคม",
    "September" : "กันยายน",
    "October" : "ตุลาคม",
    "November" : "พฤศจิกายน",
    "December" : "ธันวาคม",
    "Jan." : "ม.ค.",
    "Feb." : "ก.พ.",
    "Mar." : "มี.ค.",
    "Apr." : "เม.ย.",
    "May." : "พ.ค.",
    "Jun." : "มิ.ย.",
    "Jul." : "ก.ค.",
    "Aug." : "ส.ค.",
    "Sep." : "ก.ย.",
    "Oct." : "ต.ค.",
    "Nov." : "พ.ย.",
    "Dec." : "ธ.ค.",
    "A valid password must be provided" : "ต้องระบุรหัสผ่านที่ถูกต้อง",
    "Login canceled by app" : "การเข้าสู่ระบบถูกยกเลิกโดยแอป",
    "a safe home for all your data" : "บ้านที่ปลอดภัยสำหรับข้อมูลทั้งหมดของคุณ",
    "Application is not enabled" : "แอปพลิเคชันยังไม่ได้เปิดใช้งาน",
    "Authentication error" : "ยืนยันตัวตนผิดพลาด",
    "Token expired. Please reload page." : "รหัสยืนยันความถูกต้องหมดอายุ กรุณาโหลดหน้าเว็บใหม่",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "ไม่มีไดรเวอร์ฐานข้อมูล (sqlite, mysql, or postgresql) ที่ถูกติดตั้ง",
    "PHP module %s not installed." : "โมดูล PHP %s ไม่ได้ถูกติดตั้ง",
    "Please ask your server administrator to install the module." : "โปรดสอบถามผู้ดูแลระบบเซิร์ฟเวอร์ของคุณเพื่อติดตั้งโมดูล",
    "PHP setting \"%s\" is not set to \"%s\"." : "การตั้งค่า PHP \"%s\" ไม่ได้ตั้งค่าเป็น \"%s\"",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "การปรับการตั้งค่านี้ใน php.ini จะทำให้ Nextcloud กลับมาทำงานอีกครั้ง",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "เห็นได้ชัดว่า PHP มีการตั้งค่าเพื่อดึงบล็อกเอกสารแบบอินไลน์ ซึ่งจะทำให้แอปหลักหลายแอปไม่สามารถเข้าถึงได้",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "ปัญหานี้อาจเกิดจาก cache/accelerator เช่น Zend OPcache หรือ eAccelerator",
    "PHP modules have been installed, but they are still listed as missing?" : "โมดูล PHP ได้รับการติดตั้งแล้ว แต่ยังคงขึ้นว่าหายไปหรือไม่?",
    "Please ask your server administrator to restart the web server." : "โปรดสอบถามผู้ดูแลระบบเซิร์ฟเวอร์ของคุณเพื่อเริ่มระบบเว็บเซิร์ฟเวอร์ใหม่",
    "Could not obtain lock type %d on \"%s\"." : "ไม่สามารถรับล็อคชนิด %d บน \"%s\"",
    "Storage unauthorized. %s" : "การจัดเก็บข้อมูลไม่ได้รับอนุญาต %s",
    "Storage incomplete configuration. %s" : "การตั้งค่าการจัดเก็บข้อมูลไม่ครบ %s",
    "Storage connection error. %s" : "ข้อผิดพลาดการเชื่อมต่อพื้นที่จัดเก็บข้อมูล %s",
    "Storage is temporarily not available" : "พื้นที่จัดเก็บข้อมูลไม่สามารถใช้งานได้ชั่วคราว",
    "Storage connection timeout. %s" : "หมดเวลาการเชื่อมต่อพื้นที่จัดเก็บข้อมูล %s",
    "Text" : "ข้อความ",
    "Translate" : "แปลภาษา",
    "File name is a reserved word" : "ชื่อแฟ้มเป็นคำสงวน",
    "File name contains at least one invalid character" : "ชื่อไฟล์มีตัวอักษรที่ไม่ถูกต้องอย่างน้อย 1 ตัว",
    "File name is too long" : "ชื่อไฟล์ยาวเกินไป",
    "Users" : "ผู้ใช้งาน",
    "Open »%s«" : "เปิด »%s«",
    "File is currently busy, please try again later" : "ไฟล์กำลังใช้งานอยู่ โปรดลองอีกครั้งในภายหลัง"
},
"nplurals=1; plural=0;");

==> nextcloud-32.0.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/lib/l10n/th.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "ไม่สามารถเขียนลงในไดเรกทอรี \"config\"!",
    "This can usually be fixed by giving the web server write access to the config directory." : "โดยปกติสามารถแก้ไขได้โดยการให้สิทธิ์การเขียนสำหรับเว็บเซิร์ฟเวอร์ไปยังไดเร็กทอรี config",
    "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "แต่หากคุณต้องการให้ไฟล์ config.php อ่านอย่างเดียว ให้ตั้งค่าตัวเลือก \"config_is_read_only\" เป็น true",
    "See %s" : "ดู %s",
    "Sample configuration detected" : "ตรวจพบการกำหนดค่าตัวอย่าง",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "เราตรวจพบว่าการกำหนดค่าตัวอย่างถูกคัดลอกมา การกำหนดค่าลักษณะนี้สามารถทำลายการติดตั้งของคุณและไม่ได้รับการสนับสนุน โปรดอ่านเอกสารประกอบก่อนที่จะดำเนินการเปลี่ยนแปลงใน config.php",
    "The page could not be found on the server." : "ไม่พบหน้านี้บนเซิร์ฟเวอร์",
    "%s email verification" : "การยืนยันอีเมล %s",
    "Email verification" : "การยืนยันอีเมล",
    "Click the following button to confirm your email." : "คลิกปุ่มต่อไปนี้เพื่อยืนยันอีเมลของคุณ",
    "Click the following link to confirm your email." : "คลิกลิงก์ต่อไปนี้เพื่อยืนยันอีเมลของคุณ",
    "Confirm your email" : "ยืนยันอีเมล",
    "Other activities" : "กิจกรรมอื่น ๆ",
    "%1$s and %2$s" : "%1$s และ %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s และ %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s และ %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s และ %5$s",
    "PHP %s or higher is required." : "จำเป็นต้องมี PHP รุ่น %s หรือที่สูงกว่า ",
    "PHP with a version lower than %s is required." : "จำเป็นต้องมี PHP รุ่นต่ำกว่า %s",
    "%sbit or higher PHP required." : "จำเป็นต้องมี PHP %s บิตหรือสูงกว่า",
    "The command line tool %s could not be found" : "ไม่พบเครื่องมือบรรทัดคำสั่ง %s ",
    "The library %s is not available." : "ไลบรารี %s ไม่สามารถใช้ได้",
    "Server version %s or higher is required." : "จำเป็นต้องใช้เซิร์ฟเวอร์รุ่น %s หรือสูงกว่า",
    "Server version %s or lower is required." : "จำเป็นต้องใช้เซิร์ฟเวอร์รุ่น %s หรือต่ำกว่า",
    "Authentication" : "การตรวจสอบสิทธิ์",
    "Unknown filetype" : "ชนิดไฟล์ที่ไม่รู้จัก",
    "Invalid image" : "รูปภาพไม่ถูกต้อง",
    "Files" : "ไฟล์",
    "today" : "วันนี้",
    "tomorrow" : "พรุ่งนี้",
    "yesterday" : "เมื่อวานนี้",
    "_in %n day_::_in %n days_" : ["ใน %n วัน"],
    "_%n day ago_::_%n days ago_" : ["%n วันที่ผ่านมา"],
    "next month" : "เดือนถัดไป",
    "last month" : "เดือนที่แล้ว",
    "_in %n month_::_in %n months_" : ["ใน %n เดือน"],
    "_%n month ago_::_%n months ago_" : ["%n เดือนที่ผ่านมา"],
    "next year" : "ปีถัดไป",
    "last year" : "ปีที่แล้ว",
    "_%n year ago_::_%n years ago_" : ["%n ปีที่ผ่านมา"],
    "_%n hour ago_::_%n hours ago_" : ["%n ชั่วโมงที่ผ่านมา"],
    "_%n minute ago_::_%n minutes ago_" : ["%n นาทีที่ผ่านมา"],
    "in a few seconds" : "ในไม่กี่วินาที",
    "seconds ago" : "วินาทีที่ผ่านมา",
    "Empty file" : "ไฟล์ว่าง",
    "Dot files are not allowed" : "ไม่อนุญาตไฟล์จุด",
    "File already exists" : "มีไฟล์นี้อยู่แล้ว",
    "Templates" : "เทมเพลต",
    "Filename contains at least one invalid character" : "ชื่อไฟล์มีตัวอักษรที่ไม่ถูกต้องอย่างน้อย 1 ตัว",
    "Empty filename is not allowed" : "ชื่อไฟล์ห้ามว่างเปล่า",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "แอป \"%s\" ไม่สามารถติดตั้งได้ เพราะไฟล์ appInfo ไม่สามารถอ่านได้",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "ไม่สามารถติดตั้งแอป \"%s\" เนื่องจากแอปเข้ากับเซิร์ฟเวอร์รุ่นนี้ไม่ได้",
    "__language_name__" : "ไทย",
    "Apps" : "แอป",
    "Personal settings" : "การตั้งค่าส่วนบุคคล",
    "Administration settings" : "การตั้งค่าการดูแลระบบ",
    "Settings" : "การตั้งค่า",
    "Log out" : "ออกจากระบบ",
    "Accounts" : "บัญชี",
    "Email" : "อีเมล",
    "Fediverse" : "เฟดิเวิร์ส",
    "View %s on the fediverse" : "ดู %s บนเฟดิเวิร์ส",
    "Phone" : "โทรศัพท์",
    "Twitter" : "ทวิตเตอร์",
    "Website" : "เว็บไซต์",
    "Address" : "ที่อยู่",
    "Profile picture" : "รูปภาพโปรไฟล์",
    "About" : "เกี่ยวกับ",
    "Display name" : "ชื่อที่แสดง",
    "Additional settings" : "การตั้งค่าเพิ่มเติม",
    "Oracle connection could not be established" : "ไม่สามารถสร้างการเชื่อมต่อกับ Oracle ",
    "For the best results, please consider using a GNU/Linux server instead." : "เพื่อให้ได้ผลลัพธ์ที่ดีที่สุด โปรดพิจารณาใช้เซิร์ฟเวอร์ GNU/Linux แทน",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "ดูเหมือนว่าเซิร์ฟเวอร์ %s นี้ทำงานบน PHP 32 บิต และ open_basedir ได้ถูกกำหนดค่าใน php.ini ซึ่งจะมีปัญหากับไฟล์ที่มีขนาดใหญ่กว่า 4 GB และไม่แนะนำให้ใช้",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "กรุณาลบการตั้งค่า open_basedir ใน php.ini ของคุณ หรือเปลี่ยนไปใช้ PHP รุ่น 64 บิตแทน",
    "Set an admin password." : "ตั้งค่ารหัสผ่านผู้ดูแลระบบ",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "แบ็กเอนด์การแชร์ %s ต้องใช้อินเตอร์เฟซ OCP\\Share_Backend",
    "Sharing backend %s not found" : "ไม่พบแบ็กเอนด์การแชร์ %s",
    "Sharing backend for %s not found" : "ไม่พบแบ็กเอนด์การแชร์สำหรับ %s",
    "Unknown share type" : "ไม่รู้จักประเภทของแชร์",
    "You are not allowed to share %s" : "คุณไม่ได้รับอนุญาตให้แชร์ %s",
    "Cannot increase permissions of %s" : "ไม่สามารถเพิ่มสิทธิ์ของ %s",
    "Expiration date is in the past" : "วันหมดอายุอยู่ในอดีต",
    "Could not find category \"%s\"" : "ไม่สามารถหาหมวดหมู่ \"%s\"",
    "Sunday" : "วันอาทิตย์",
    "Monday" : "วันจันทร์",
    "Tuesday" : "วันอังคาร",
    "Wednesday" : "วันพุธ",
    "Thursday" : "วันพฤหัสบดี",
    "Friday" : "วันศุกร์",
    "Saturday" : "วันเสาร์",
    "Sun." : "อา.",
    "Mon." : "จ.",
    "Tue." : "อ.",
    "Wed." : "พ.",
    "Thu." : "พฤ.",
    "Fri." : "ศ.",
    "Sat." : "ส.",
    "Su" : "อา",
    "Mo" : "จ",
    "Tu" : "อ",
    "We" : "พ",
    "Th" : "พฤ",
    "Fr" : "ศ",
    "Sa" : "ส",
    "January" : "มกราคม",
    "February" : "กุมภาพันธ์",
    "March" : "มีนาคม",
    "April" : "เมษายน",
    "May" : "พฤษภาคม",
    "June" : "มิถุนายน",
    "July" : "กรกฏาคม",
    "August" : "สิงหาคม",
    "September" : "กันยายน",
    "October" : "ตุลาคม",
    "November" : "พฤศจิกายน",
    "December" : "ธันวาคม",
    "Jan." : "ม.ค.",
    "Feb." : "ก.พ.",
    "Mar." : "มี.ค.",
    "Apr." : "เม.ย.",
    "May." : "พ.ค.",
    "Jun." : "มิ.ย.",
    "Jul." : "ก.ค.",
    "Aug." : "ส.ค.",
    "Sep." : "ก.ย.",
    "Oct." : "ต.ค.",
    "Nov." : "พ.ย.",
    "Dec." : "ธ.ค.",
    "A valid password must be provided" : "ต้องระบุรหัสผ่านที่ถูกต้อง",
    "Login canceled by app" : "การเข้าสู่ระบบถูกยกเลิกโดยแอป",
    "a safe home for all your data" : "บ้านที่ปลอดภัยสำหรับข้อมูลทั้งหมดของคุณ",
    "Application is not enabled" : "แอปพลิเคชันยังไม่ได้เปิดใช้งาน",
    "Authentication error" : "ยืนยันตัวตนผิดพลาด",
    "Token expired. Please reload page." : "รหัสยืนยันความถูกต้องหมดอายุ กรุณาโหลดหน้าเว็บใหม่",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "ไม่มีไดรเวอร์ฐานข้อมูล (sqlite, mysql, or postgresql) ที่ถูกติดตั้ง",
    "PHP module %s not installed." : "โมดูล PHP %s ไม่ได้ถูกติดตั้ง",
    "Please ask your server administrator to install the module." : "โปรดสอบถามผู้ดูแลระบบเซิร์ฟเวอร์ของคุณเพื่อติดตั้งโมดูล",
    "PHP setting \"%s\" is not set to \"%s\"." : "การตั้งค่า PHP \"%s\" ไม่ได้ตั้งค่าเป็น \"%s\"",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "การปรับการตั้งค่านี้ใน php.ini จะทำให้ Nextcloud กลับมาทำงานอีกครั้ง",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "เห็นได้ชัดว่า PHP มีการตั้งค่าเพื่อดึงบล็อกเอกสารแบบอินไลน์ ซึ่งจะทำให้แอปหลักหลายแอปไม่สามารถเข้าถึงได้",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "ปัญหานี้อาจเกิดจาก cache/accelerator เช่น Zend OPcache หรือ eAccelerator",
    "PHP modules have been installed, but they are still listed as missing?" : "โมดูล PHP ได้รับการติดตั้งแล้ว แต่ยังคงขึ้นว่าหายไปหรือไม่?",
    "Please ask your server administrator to restart the web server." : "โปรดสอบถามผู้ดูแลระบบเซิร์ฟเวอร์ของคุณเพื่อเริ่มระบบเว็บเซิร์ฟเวอร์ใหม่",
    "Could not obtain lock type %d on \"%s\"." : "ไม่สามารถรับล็อคชนิด %d บน \"%s\"",
    "Storage unauthorized. %s" : "การจัดเก็บข้อมูลไม่ได้รับอนุญาต %s",
    "Storage incomplete configuration. %s" : "การตั้งค่าการจัดเก็บข้อมูลไม่ครบ %s",
    "Storage connection error. %s" : "ข้อผิดพลาดการเชื่อมต่อพื้นที่จัดเก็บข้อมูล %s",
    "Storage is temporarily not available" : "พื้นที่จัดเก็บข้อมูลไม่สามารถใช้งานได้ชั่วคราว",
    "Storage connection timeout. %s" : "หมดเวลาการเชื่อมต่อพื้นที่จัดเก็บข้อมูล %s",
    "Images" : "รูปภาพ",
    "Text" : "ข้อความ",
    "Translate" : "แปลภาษา"
},
"nplurals=1; plural=0;");
